#
# spec file for package python-pyipp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyipp
Version:        0.17.0
Release:        1.2
Summary:        Asynchronous Python client for Internet Printing Protocol (IPP)
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ctalkington/python-ipp
Source0:        https://files.pythonhosted.org/packages/source/p/pyipp/pyipp-%{version}.tar.gz
Source1:        https://github.com/ctalkington/python-ipp/archive/%{version}.tar.gz#/pyipp-%{version}-gh-tests.tar.gz
BuildRequires:  %{python_module aiohttp >= 3.6.2}
BuildRequires:  %{python_module async-timeout}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module covdefaults}
BuildRequires:  %{python_module deepmerge >= 0.1.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module syrupy}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module yarl >= 1.4.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aiohttp >= 3.6.2
Requires:       python-deepmerge >= 0.1.0
Requires:       python-yarl >= 1.4.2
BuildArch:      noarch
%python_subpackages

%description
Asynchronous Python client for Internet Printing Protocol (IPP).

%prep
%autosetup -p1 -n pyipp-%{version} -a1
ln -s python-ipp-%{version}/tests/ tests
rm tests/test_client.py  tests/test_interface.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pyipp
%{python_sitelib}/pyipp-%{version}.dist-info

%changelog
* Fri Jan 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.17.0
  * Fix parsing of IPP collections @ctalkington (#572)
  * Fix finishings enum @ctalkington (#604)
  * Parse more enums to python enums @ctalkington (#573)
  * Support appending pre-encoded data when serializing @dellorogiulio (#510)
  * Track when printer was last booted using uptime @ctalkington (#599)
  * Add media and center-of-pixel attributes tags to map @so-saf (#598)
  * Use syrupy snapshots for parser tests @ctalkington (#571)
  * Update dependency pylint to v3.2.0 @renovate (#569)
  * Update actions/checkout action to v4.1.6 @renovate (#570)
  * Update dependency node to v20.14.0 @renovate (#583)
  * Update actions/checkout action to v4.2.1 @renovate (#586)
  * Update codecov/codecov-action action to v4.6.0 @renovate (#576)
  * Update dependency pytest to v8.3.3 @renovate (#577)
  * Update dependency pytest-asyncio to v0.24.0 @renovate (#578)
  * Update dependency prettier to v3.3.3 @renovate (#584)
  * Update dependency coverage to v7.6.2 @renovate (#581)
  * Update dependency codespell to v2.3.0 @renovate (#580)
  * Update dependency pylint to v3.3.1 @renovate (#574)
  * Update pypa/gh-action-pypi-publish action to v1.10.3 @renovate (#600)
  * Update dependency ruff to v0.6.9 @renovate (#579)
  * Update actions/setup-python action to v5.2.0 @renovate (#602)
  * Update dependency safety to v3.2.8 @renovate (#601)
  * Update dependency yarl to v1.14.0 @renovate (#603)
  * Update dependency aiohttp to v3.10.2 [SECURITY] @renovate (#595)
- Update BuildRequires from pyproject.toml
* Mon Aug  5 2024 Dirk Müller <dmueller@suse.com>
- update to 0.16.0:
  * Allow passing IPP version to IPP dataclass @ctalkington
  * Use trusted publisher for release workflow @ctalkington
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.15.0:
  * Add ability to retrieve Printer model as dictionary
- update to 0.14.5:
  * Make sure uri_supported is always a list @joostlek
  * Ensure uri supported fallback is string @ctalkington
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.4:
  * Fix type of info.printer_uri_supported
  * fix: remove I/O in the event loop when creating IPP
  * Convert client class to dataclass
- update to 0.14.0:
  * Export all models
  * Thaw models
- update to 0.13.0:
  * Allow for markers and URIs being single values
  * Improvements to serializer
  * Improve typing
  * Refactor models
  * Configure Renovate
  * Improvements to serializer
  * Improve typing
  * Define exports
  * Improve models test coverage
  * Refactor models
  * Development workflow updates
- update to 0.12.1:
  * Add marker/other attributes to default attributes
- update to 0.12.0:
  * This release requires Python 3.9
  * Use encoded value length when serializing attributes
  * Accept successful and informational status codes
  * Add additional tags/enum cleanup. Fix date parsing.
  * Adding printer-more-info support
  * Packaging Overhaul (Python 3.9)
  * Add Kyocera to known makes
  * Parse unsupported-attributes group
  * Add KYOCERA ECOSYS M2540dn test fixture
  * Update Tests
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- spec file cleanups
* Mon Apr 13 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-pyipp 0.11.0
